@@ -35,6 +35,7 @@
 //!
 //! |Feature           |Description                     |
 //! |------------------|--------------------------------|
+//! |cookie            | Support for Cookie             |
 //! |websocket         | Support for WebSocket          |
 //! |multipart         | Support for Multipart          |
 //! |sse               | Support Server-Sent Events (SSE)       |
@@ -43,6 +44,8 @@
 //! |tempfile          | Support for [`tempfile`](https://crates.io/crates/tempfile) |
 //! |tower-compat      | Adapters for `tower::Layer` and `tower::Service`. |
 
+#![doc(html_favicon_url = "https://poem.rs/assets/favicon.ico")]
+#![doc(html_logo_url = "https://poem.rs/assets/logo.png")]
 #![forbid(unsafe_code)]
 #![deny(private_in_public, unreachable_pub)]
 #![cfg_attr(docsrs, feature(doc_cfg))]
@@ -73,5 +76,5 @@ pub use poem_derive::handler;
 pub use request::{Request, RequestBuilder, RequestParts};
 pub use response::{Response, ResponseBuilder, ResponseParts};
 pub use route::{route, RouteMethod};
-pub use server::Server;
+pub use server::{warps_endpoint, Server};
 pub use web::{FromRequest, IntoResponse, RequestBody};
