@@ -5,6 +5,7 @@ use std::{
         atomic::{AtomicUsize, Ordering},
         Arc,
     },
+    time::SystemTime,
 };
 
 use hyper::server::conn::Http;
@@ -152,9 +153,20 @@ async fn serve_connection(
                 );
 
                 let fut = async move {
+                    let now = SystemTime::now();
                     let resp: http::Response<hyper::Body> =
                         ep.call((req, remote_addr).into()).await.into();
-                    ::tracing::info!(status = %resp.status(), "respond");
+                    match now.elapsed() {
+                        Ok(duration) => tracing::info!(
+                            status = %resp.status(),
+                            duration = ?duration,
+                            "response"
+                        ),
+                        Err(_) => tracing::info!(
+                            status = %resp.status(),
+                            "response"
+                        ),
+                    }
                     resp
                 }
                 .instrument(span);
@@ -172,7 +184,6 @@ async fn serve_connection(
 
 #[doc(hidden)]
 pub fn warps_endpoint(ep: impl Endpoint) -> impl Endpoint<Output = Response> {
-    println!("1");
     #[cfg(feature = "cookie")]
     let ep = ep.with(CookieJarManager);
     ep.map_to_response()
